@@ -17,13 +17,12 @@ from ..var import get_circle
 
 
 def compute_stim_map(cube_der):
-    """
-    Computes the STIM detection map.
+    """ Computes the STIM detection map.
 
     Parameters
     ----------
     cube_der : 3d numpy ndarray
-        Input de-rotated cube, e.g. output 'residuals_cube_' from
+        Input de-rotated cube, e.g. ``residuals_cube_`` output from
         ``vip_hci.pca.pca``.
 
     Returns
@@ -39,9 +38,9 @@ def compute_stim_map(cube_der):
     return get_circle(detection_map, int(np.round(n/2.)))
 
 
-def compute_inverse_stim_map(cube, angle_list):
-    """
-    Computes the STIM detection map.
+def compute_inverse_stim_map(cube, angle_list, imlib='opencv',
+                             interpolation='lanczos4'):
+    """ Computes the inverse STIM detection map.
 
     Parameters
     ----------
@@ -49,14 +48,19 @@ def compute_inverse_stim_map(cube, angle_list):
         Non de-rotated residuals from reduction algorithm, eg. output residuals
         from ``vip_hci.pca.pca``.
     angle_list : numpy ndarray, 1d
-        Corresponding parallactic angle for each frame.    
-
+        Corresponding parallactic angle for each frame.  
+    imlib: str, opt
+        See description of vip_hci.preproc.frame_derotate()
+    interpolation: str, opt
+        See description of vip_hci.preproc.frame_derotate()
+        
     Returns
     -------
     inverse_stim_map : 2d ndarray
         Inverse STIM detection map.
     """
     t, n, _ = cube.shape
-    cube_inv_der = cube_derotate(cube, -angle_list)
+    cube_inv_der = cube_derotate(cube, -angle_list, imlib=imlib, 
+                                 interpolation=interpolation)
     inverse_stim_map = compute_stim_map(cube_inv_der)
     return inverse_stim_map
\ No newline at end of file
